Learn R Programming

repmod (version 0.4.11)

rob.ci: Function to compute bootstrap confidence intervals for robust linear regression models

Description

Estimates confidence intervals for rlm models.

Usage

rob.ci(x, level = 0.95, maxit = 200, R = 2000)

Value

A matrix with bootstrap confidence intervals for each variable in the model

Arguments

x

A rlm object

level

Confidence level for the interval

maxit

Maximum number of iterations per fit

R

Number of boostrap samples